package com.diagbot.client;

import com.diagbot.client.bean.CalculateData;
import com.diagbot.client.bean.GdbResponse;
import com.diagbot.client.bean.Response;
import com.diagbot.client.bean.ResponseData;
import com.diagbot.client.bean.SearchData;
import com.diagbot.client.hystrix.AiptServiceHystrix;
import com.diagbot.dto.ConceptIntroduceDTO;
import com.diagbot.dto.DisScaleDTO;
import com.diagbot.dto.DisTypeDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.ScaleContent;
import com.diagbot.vo.ConceptIntroduceVO;
import com.diagbot.vo.DisScaleVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * @Description:调用中间层服务
 * @Author: Mark Huang
 * @time: 2019/03/25 19:15
 */
@FeignClient(value = "aipt-service", fallback = AiptServiceHystrix.class)
public interface AiptServiceClient {
    @PostMapping(value = "/clinicaldata/processData")
    Response<ResponseData> aiptData(@RequestBody SearchData searchData);

    @PostMapping(value = "/clinicaldata/scale")
    Response<Map<String, Object>> scale(@RequestBody SearchData searchData);

    @PostMapping(value = "/nlpService/symptomFeature")
    Response<List<Map<String, Object>>> symptomFeaturePageData(@RequestParam("text") String text);

    @PostMapping("/clinicaldata/highRisk")
    Response<GdbResponse> highRisk(@RequestBody SearchData searchData);

    @PostMapping(value = "/clinicaldata/scaleCalc")
    Response<Map<String, Object>> scaleCalc(@RequestBody CalculateData calculateData);

    @PostMapping(value = "/scale/getList")
    RespDTO<List<DisScaleDTO>> getList(@RequestBody DisScaleVO scaleVO);

    @PostMapping(value = "/disType/getDisType")
    RespDTO<DisTypeDTO> getDisType();

    @PostMapping(value = "/clinicaldata/getScale")
    RespDTO<List<ScaleContent>> getScale(@RequestBody SearchData searchData);

    @PostMapping(value = "/conceptDetail/getConceptDetail")
    RespDTO<ConceptIntroduceDTO> getConceptDetail(@Valid @RequestBody ConceptIntroduceVO conceptIntroduceVO);
}
